# Instalation

### 1. Install Package:

	- bash
	- pip install cytomat-tests

### 2. Use package
    - from cytomat import Cytomat
    - c = Cytomat("COM{int}")

# Debugging

### debugging communication with Cytomat

#### install RS232 Terminal, e.g. Termite
https://termite.software.informer.com/3.4/



# Unofficial Python interface for Thermo Fisher Scientific Cytomat devices
Find the documentation [here](https://umg-pharma-lab-automation.pages.gwdg.de/cytomat-python).
